@@ -78,7 +78,7 @@ class Organizations(object):
 
         return WorkOSOrganization.construct_from_response(response).to_dict()
 
-    def create_organization(self, organization):
+    def create_organization(self, organization, idempotency_key=None):
         """Create an organization
 
         Args:
@@ -88,14 +88,20 @@ class Organizations(object):
                     within the Organization allow profiles that are outside of the Organization's
                     configured User Email Domains. (Optional)
                 organization[domains] (list) - List of domains that belong to the organization
+            idempotency_key (str) - Idempotency key for creating an organization. (Optional)
 
         Returns:
             dict: Created Organization response from WorkOS.
         """
+        headers = {}
+        if idempotency_key:
+            headers["idempotency-key"] = idempotency_key
+
         response = self.request_helper.request(
             ORGANIZATIONS_PATH,
             method=REQUEST_METHOD_POST,
             params=organization,
+            headers=headers,
             token=workos.api_key,
         )
 
