@@ -33,3 +33,7 @@ class ConnectionType(Enum):
     ShibbolethSAML = "ShibbolethSAML"
     SimpleSamlPhpSAML = "SimpleSamlPhpSAML"
     VMwareSAML = "VMwareSAML"
+
+    @classmethod
+    def has_value(cls, value):
+        return value in cls._value2member_map_
